@@ -8,12 +8,14 @@
 #ifndef KHTMLTTS_H
 #define KHTMLTTS_H
 
-#include <kparts/plugin.h>
+#include <konq_kpart_plugin.h>
+
+class QTextToSpeech;
 
 /**
  * KHTML KParts Plugin
  */
-class KHTMLPluginTTS : public KParts::Plugin
+class KHTMLPluginTTS : public KonqParts::Plugin
 {
     Q_OBJECT
 public:
@@ -29,6 +31,8 @@ public:
     ~KHTMLPluginTTS() override;
 public Q_SLOTS:
     void slotReadOut();
+private:
+    std::unique_ptr<QTextToSpeech> m_tts;
 };
 
 #endif
